version 8.2
clear
set logtype text
set more off
set matsize 200
tempfile pia

capture mkdir "brazrloc/estmat/v4"
capture mkdir "brazrloc/estmat/v4/ext"
capture mkdir "brazrloc/tex/v4"
capture mkdir "brazrloc/tex/v4/ext"
capture mkdir "brazrloc/tex/v4/ext/corr"
capture mkdir "brazrloc/tex/v4/ext/summ"
capture mkdir "brazrloc/graphs/v4"
capture mkdir "brazrloc/graphs/v4/ext"

capture log close
log using "brazrloc/logs/tariff-data.log", replace


* TABLE: TARIFF PROFILES *

use "brazaux/auxil/tariff-data.dta", clear

// TIME SERIES

preserve
drop if year==98
gen _empl88 = employment if year==88
egen empl88 = mean(_empl88), by(niv50)
drop _empl88
collapse (mean) tarfoutp [w=empl88], by(year) fast cw
merge using "brazrloc/tex/v4/natl-maleprime/duration/indnorloc48m_tbl.dta"
qui count if int(real(_rowname))-1900~=year
if `r(N)'>0  STOP  // non-matching years
drop _m _rowname
gen _indnorloc = indnorloc if year==89 | year==92 | year==97
format tarfoutp _indnorloc %9.2f
twoway bar tarfoutp year, bcolor(gs12) yaxis(1) || connected indnorloc year, yaxis(2) msymbol(T) mcolor(gs6) clpattern(solid) || sc tarfoutp year, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _indnorloc year, mlabel(_indnorloc) mlabposition(2) mlabcolor(black) msymbol(i) yaxis(2) || connected tarfoutp year, yaxis(1) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(.1 .25)) ytitle("Workers Without Reallocation (share)", axis(2)) ylabel(.1(.05).25, axis(2)) yline(.15 .175 .2 .225 .25, axis(2) lcolor(gs14)) legend( order(1 2 4) label(1 "Product Market Tariff") label(2) label(4 "Displaced Workers Without Reallocation") ) graphregion(color(white)) scheme(sj) 
graph export "brazrloc/graphs/v4/natl-maleprime/laborstats/tarfoutp-indnorloc48-86-98.eps", replace

restore, preserve
drop if year==98
gen _empl88 = employment if year==88
egen empl88 = mean(_empl88), by(niv50)
drop _empl88
collapse (mean) tarfoutp [w=empl88], by(year) fast cw
merge using "brazrloc/tex/v4/natl-maleprime/duration/mo2rehr48m_tbl.dta"
qui count if int(real(_rowname))-1900~=year
if `r(N)'>0  STOP  // non-matching years
drop _m _rowname
gen _mo2rehir = mo2rehir if year==89 | year==92 | year==97
format tarfoutp _mo2rehir %9.2f
twoway bar tarfoutp year, bcolor(gs12) yaxis(1) || connected mo2rehir year, yaxis(2) msymbol(T) mcolor(gs6) clpattern(solid) || sc tarfoutp year, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _mo2rehir year, mlabel(_mo2rehir) mlabposition(3) mlabcolor(black) msymbol(i) yaxis(2) || connected tarfoutp year, yaxis(1) msymbol(none) ||, xlabel(86(1)97) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(5 10)) ytitle("Reallocation Duration (months)", axis(2)) yline(6 7 8 9 10, axis(2) lcolor(gs14)) legend( order(1 2 3) label(1 "Product Market Tariff") label(2) label(3 "Reallocation Duration") ) graphregion(color(white)) scheme(sj) 
graph export "brazrloc/graphs/v4/natl-maleprime/laborstats/tarfoutp-mo2rehir48-86-98.eps", replace

restore, preserve
gen _empl88 = employment if year==88
egen empl88 = mean(_empl88), by(niv50)
drop _empl88
collapse (mean) tarfoutp [w=empl88], by(year) fast cw
merge using "brazrloc/tex/v4/natl-maleprime/duration/mo2rehr36m_tbl.dta"
qui count if int(real(_rowname))-1900~=year
if `r(N)'>0  STOP  // non-matching years
drop _m _rowname
gen _mo2rehir = mo2rehir if year==89 | year==92 | year==97
format tarfoutp _mo2rehir %9.2f
twoway bar tarfoutp year, bcolor(gs12) yaxis(1) || connected mo2rehir year, yaxis(2) msymbol(T) mcolor(gs6) clpattern(solid) || sc tarfoutp year, mlabel(tarfoutp) mlabposition(12) mlabcolor(black) msymbol(i) yaxis(1) || sc _mo2rehir year, mlabel(_mo2rehir) mlabposition(3) mlabcolor(black) msymbol(i) yaxis(2) || connected tarfoutp year, yaxis(1) msymbol(none) ||, xlabel(86(1)98) xtitle("Calendar year") ylabel(none, axis(1)) yscale(axis(1) r(0 1)) ytitle("Product Market Tariff (ad valorem)", axis(1)) yscale(axis(2) r(4 9)) ytitle("Reallocation Duration (months)", axis(2)) yline(5 6 7 8 9, axis(2) lcolor(gs14)) legend( order(1 2 3) label(1 "Product Market Tariff") label(2) label(3 "Reallocation Duration") ) graphregion(color(white)) scheme(sj) 
graph export "brazrloc/graphs/v4/natl-maleprime/laborstats/tarfoutp-mo2rehir36-86-98.eps", replace
restore


// SECTOR PROFILES

preserve
keep if year==90 | year==97
keep niv50 year tarfoutp
sort year tarfoutp
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename tarfoutp tarfoutp_
reshape wide tarfoutp, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected tarfoutp_90 tarfoutp_97 secnum, ytitle("Ad-valorem Tariff Level") xlabel(#31, valuelabel) legend( label(1 "Sales Market Tariffs 1990") label(2 "Sales Market Tariffs 1997") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/tarfoutp-90-97.eps", replace
restore

preserve
keep if year==90 | year==97
keep niv50 year tarfintm tarfoutp
sort year tarfoutp
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename tarfintm tarfintm_
reshape wide tarfoutp tarfintm, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected tarfintm_90 tarfintm_97 secnum, ytitle("Ad-valorem Tariff Level") xlabel(#31, valuelabel) legend( label(1 "Input Market Tariffs 1990") label(2 "Input Market Tariffs 1997") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/tarfintm-90-97.eps", replace 
restore

preserve
keep if year==90 | year==97
keep niv50 year erp tarfoutp
sort year tarfoutp
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename erp erp_
reshape wide tarfoutp erp, i(niv50) j(year)
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected erp_90 erp_97 secnum, ytitle("Ad-valorem Effective Rate of Protection") xlabel(#31, valuelabel) legend( label(1 "ERP 1990") label(2 "ERP 1997") ) graphregion(color(white)) scheme(sj) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */ msymbol(T O)
graph export "brazrloc/graphs/v4/ext/erp-90-97.eps", replace 
restore

preserve
keep if year==90 | year==97
keep niv50 year tarfoutp herfsale
sort year tarfoutp
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename tarfoutp tarfoutp_ 
rename herfsale herfsale_
reshape wide tarfoutp herfsale, i(niv50) j(year)
gen tarfdiff = tarfoutp_97 - tarfoutp_90
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected herfsale_90 tarfdiff secnum, ylab(-1(.25).5) ytitle("Ad-valorem Tariff Level, Herfindahl Index") xlabel(#31, valuelabel) legend( label(1 "Herfindahl Idx (Sales) 1990") label(2 "Tariff Difference 1997-90") ) graphregion(color(white)) scheme(sj) /* clcolor(dkgreen sienna) mcolor(dkgreen sienna) */ msymbol(T O) yline(0)
graph export "brazrloc/graphs/v4/ext/herfsale-90-97.eps", replace
restore

preserve
keep if year==90 | year==97
keep niv50 year tarfoutp herfsale survival
sort year tarfoutp
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
gen exits = 1 - survival
drop survival
rename tarfoutp tarfoutp_ 
rename herfsale herfsale_
rename exits exits_
reshape wide tarfoutp herfsale exits, i(niv50) j(year)
gen tarfdiff = tarfoutp_97 - tarfoutp_90
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected exits_90 herfsale_90 secnum, ytitle("Share of Exiting Firms, Herfindahl Index") xlabel(#31, valuelabel) legend( label(1 "Firm Exit Rate 1990") label(2 "Herfindahl Idx (Sales) 1990") ) graphregion(color(white)) scheme(sj) /* clcolor(dkgreen sienna) mcolor(dkgreen sienna) */ msymbol(T O) yline(0)
graph export "brazrloc/graphs/v4/ext/exits-90.eps", replace
graph twoway connected exits_97 herfsale_97 secnum, ytitle("Share of Exiting Firms, Herfindahl Index") xlabel(#31, valuelabel) legend( label(1 "Firm Exit Rate 1997") label(2 "Herfindahl Idx (Sales) 1997") ) graphregion(color(white)) scheme(sj) /* clcolor(dkgreen sienna) mcolor(dkgreen sienna) */ msymbol(T O) yline(0)
graph export "brazrloc/graphs/v4/ext/exits-97.eps", replace
restore

preserve
keep if year==90 | year==97
keep niv50 year tarfoutp herfsale survival
sort year tarfoutp
gen _secnum = _n if year==90
qui summ _secnum, detail
local max = `r(max)'
egen secnum = max(_secnum), by(niv50)
drop _secnum
capture label drop sec
forvalues sec = 1/`max' {
  local lbl = niv50[`sec']
  label define sec `sec' "`lbl'", add
  }
label values secnum sec
rename tarfoutp tarfoutp_ 
rename herfsale herfsale_
rename survival survival_
reshape wide tarfoutp herfsale survival, i(niv50) j(year)
gen tarfdiff = tarfoutp_97 - tarfoutp_90
sort secnum
label var secnum "Sector (Nivel 50)"
graph twoway connected survival_90 herfsale_90 secnum, ytitle("Share of Surviving Firms, Herfindahl Index") xlabel(#31, valuelabel) legend( label(1 "Firm Survival Rate 1990") label(2 "Herfindahl Idx (Sales) 1990") ) graphregion(color(white)) scheme(sj) /* clcolor(dkgreen sienna) mcolor(dkgreen sienna) */ msymbol(T O) yline(0)
graph export "brazrloc/graphs/v4/ext/survival-90.eps", replace
graph twoway connected survival_97 herfsale_97 secnum, ytitle("Share of Surviving Firms, Herfindahl Index") xlabel(#31, valuelabel) legend( label(1 "Firm Survival Rate 1997") label(2 "Herfindahl Idx (Sales) 1997") ) graphregion(color(white)) scheme(sj) /* clcolor(dkgreen sienna) mcolor(dkgreen sienna) */ msymbol(T O) yline(0)
graph export "brazrloc/graphs/v4/ext/survival-97.eps", replace
restore


// BOX AND BAR CHARTS AT SUBSECTOR IBGE LEVEL

use subs_ibge year subs_tarfoutp subs_tarfintm using "brazrloc/auxil/sector-subsibge-moredata", clear
qui do "rais/cnae/ibge.do"
label values subs_ibge ibge
decode subs_ibge, generate(subs_string)
replace subs_string = subinstr(subs_string,"Manufacture of ","",.)
replace subs_string = upper(substr(subs_string,1,1)) + substr(subs_string,2,.)
replace subs_string = subinstr(subs_string,", and manufacturing n.e.c.","",.)
replace subs_string = subinstr(subs_string," and printing","",.)
replace subs_string = subinstr(subs_string,"telecommunications","telecomm.",.)
drop subs_ibge
encode subs_string, generate(subs_ibge)
drop subs_string
order subs_ibge

preserve
graph hbar (mean) subs_tarfoutp subs_tarfintm if year==1990 & subs_tarfoutp~=., over(subs_ibge, sort(subs_tarfoutp) descending) ylab(.1(.1).6) legend( label(1 "Product Tariff") label(2 "Input Tariff") ) blabel(bar, position(inside) format(%9.2f) color(white) size(vsmall)) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/ext/tariff-subsibge-hbar-90.eps", replace
graph hbar (mean) subs_tarfoutp subs_tarfintm if year==1997 & subs_tarfoutp~=., over(subs_ibge, sort(subs_tarfoutp) descending) ylab(.1(.1).6) legend( label(1 "Product Tariff") label(2 "Input Tariff") ) blabel(bar, position(inside) format(%9.2f) color(white) size(vsmall)) graphregion(color(white)) scheme(sj)
graph export "brazrloc/graphs/v4/ext/tariff-subsibge-hbar-97.eps", replace
restore

preserve
label var subs_tarfoutp "Annual Product-Market Tariff"
graph box subs_tarfoutp, over(year) graphregion(color(white)) scheme(sj) 
graph export "brazrloc/graphs/v4/ext/tariff-subsibge-box-86-98.eps", replace
restore

log close
