version 8.2
clear
set logtype text
set more off
set matsize 200

capture log close
log using "brazrloc/logs/compadv-by-secagg.log", replace

* EMPLOYMENT IN 1995 BY CNAE (1995 is first year of CNAE observation)
tempfile empl
insheet using "rais/base-agg/cnae/aggsec.csv", comma clear
keep if ano==1995  // use year 1990 as reference year
keep clas_cnae_95 ano n_pis
label var clas_cnae_95 "Sector (CNAE)"
label var ano "Calendar year"
label var n_pis "Number of Workers"
drop ano
rename clas_cnae_95 cnae
sort cnae
save `empl'

* FROM CNAE (ISCI2) TO NIV100
tempfile cnae niv100
use "rais/cnae/cnae-x-isic.dta", clear
sort cnae
merge cnae using `empl', nokeep  // _m==2: CNAE 0 and CNAE -1
tab _m  // _m==1: CNAE 1708 (Hunting, trapping and game propagation)
egen empl = sum(n_pis), by(isic2)
compress
keep isic2 cnae empl
duplicates drop
sort cnae isic2
sort isic2
save `cnae'
use `cnae', clear
rename cnae cnaecntrl
gen cnae = int(cnaecntrl/10)
sort cnae
joinby cnae using "brazcomp/filters/cnae2niv100", unmatched(both) _merge(_mergemf)
tab _mergemf
sort cnae
joinby cnae using "brazcomp/filters/cnae2niv100-app-agric", unmatched(both) _merge(_mergeagr) update
tab _mergeagr
tab _mergemf _mergeagr
drop _m*
keep if niv100~=.
drop cnae*
duplicates drop
sort isic2
save `niv100'

* FROM CNAE (ISCI2) TO SUBSIBGE
tempfile subsibge cnae_ibge
use "rais/cnae/cnae-x-isic.dta", clear
sort cnae
merge cnae using `empl', nokeep  // _m==2: CNAE 0 and CNAE -1
tab _m  // _m==1: CNAE 1708 (Hunting, trapping and game propagation)
egen empl = sum(n_pis), by(isic2)
compress
keep isic2 cnaestr empl
joinby cnaestr using "rais/cnae/cnae2subsibge.dta", unmatched(both) _merge(_merge)
drop sector grandsector
rename subsector subsibge
tab _m
qui count if _m~=3 & indnew~=1
if `r(N)'>0  STOP
drop if _m~=3
preserve
  keep cnaestr isic2 subsibge empl
  sort isic2 cnae subsibge
  save `cnae_ibge'
restore
drop _m* cnae* desc indinact indnew
keep if subsibge~=.
duplicates drop
sort isic2
save `subsibge'

* 2-DIGIT CNAE AND SUBSIBGE (via CNAE/ISIC2)
// Balassa comparative advantage at CNAE 2-digit level
tempfile cadvcnae2dgt
use cnae year wrld_exp wrld_tot braz_exp braz_tot using "brazaux/intl/balassa-compadv-cnae", clear
gen byte cnae2dgt = int(cnae/1000)
collapse (sum) wrld_exp wrld_tot braz_exp braz_tot, by(cnae2dgt year) fast
gen balcadv = (braz_exp/braz_tot) / (wrld_exp/wrld_tot)
label var balcadv "Balassa (1965) comp. advantage"
qui gen byte balarank = .
forvalues year = 1986/2001 {
  foreach pctile in 20 40 60 80 {
    qui egen _pc`pctile' = pctile(balcadv) if year==`year', p(`pctile')
    }
  qui replace balarank = 1 if year==`year' & balcadv<=_pc20
  qui replace balarank = 2 if year==`year' & balcadv<=_pc40 & balarank==.
  qui replace balarank = 3 if year==`year' & balcadv<=_pc60 & balarank==.
  qui replace balarank = 4 if year==`year' & balcadv<=_pc80 & balarank==.
  qui replace balarank = 5 if year==`year' & balarank==. & balcadv~=.
  drop _pc20 _pc40 _pc60 _pc80
  }
label var balarank "Quintile rank Balassa advantage"
drop wrld_exp wrld_tot braz_exp braz_tot
sort cnae2dgt year
compress
save `cadvcnae2dgt'
// CNAE 2-digit labels
insheet using "brazcomp/niv-cnae/cnae3d-en.csv", comma clear names
keep if cnae<100
rename cnae cnae2dgt
rename cnaedesc desc
count
forvalues i = 1/`r(N)' {
    local lblno = cnae2dgt[`i']
    local lbltit = desc[`i']
    label define cnae2dgt `lblno' "`lbltit'", add
    }
label define cnae2dgt 1 "Agriculture", modify
label define cnae2dgt 2 "Forestry and Logging", modify
label define cnae2dgt 5 "Fishing", modify
label values cnae2dgt cnae2dgt
qui label save cnae2dgt using "brazrloc/auxil/cnae2dgt", replace
// CNAE 2-digit SUBSIBGE concordance
use `cnae_ibge', clear
by isic2: gen byte _nummaps = _N
replace empl = empl/_nummaps
label var empl "Employment in ISIC2-CNAE cell"
drop _nummaps
keep if subsibge~=.
duplicates drop
gen byte cnae2dgt = int(real(substr(cnaestr,1,2)))
drop cnaestr isic
order cnae2dgt subsibge
sort cnae2dgt subsibge
collapse (sum) empl, by(cnae2dgt subsibge) fast
order cnae2dgt
sort cnae2dgt subsibge
egen _maxempl = max(empl), by(cnae2dgt)
gen byte indmaxempl = ( empl==_maxempl )
drop _maxempl
gen byte cnae2dgt_num = cnae2dgt
gen byte subsibge_num = subsibge
label var cnae2dgt_num "Sector (CNAE 2-digit)"
label var cnae2dgt "Sector (CNAE 2-digit)"
label var subsibge_num "Subsector IBGE"
label var empl "Employment at ISIC rev. 2"
label var indmaxempl "Max. employment at Nivel 50"
qui do brazrloc/auxil/cnae2dgt.do"
label values cnae2dgt cnae2dgt
qui do "rais/cnae/ibge.do"
label values subsibge ibge
order cnae2dgt_num cnae2dgt subsibge_num subsibge
sort cnae2dgt subsibge
outsheet using "brazrloc/auxil/cnae2dgt-subsibge-pseudoconc.csv", comma replace  // for manual processing
// Comparative Advantage Table for 1990 and 1997
insheet using "brazrloc/auxil/manual/cnae2dgt-subsibge-manual.csv", names comma clear
keep cnae2dgt_num subsibge_num
rename cnae2dgt_num cnae2dgt
rename subsibge_num subsibge
joinby cnae2dgt using `cadvcnae2dgt', unmatched(both) _merge(_merge)
tab _m
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete sector mapping
drop _m
rename balcadv cnae2dgt_balcadv
rename balarank cnae2dgt_balarank
sort subsibge year
joinby subsibge year using "brazaux/intl/balassa-compadv-subsibge", unmatched(both) _merge(_merge)
tab _m
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete sector mapping
drop _m wrld_exp wrld_tot braz_exp braz_tot
rename balcadv subsibge_balcadv
rename balarank subsibge_balarank
keep if year==1990 | year==1997
reshape wide cnae2dgt_balcadv cnae2dgt_balarank subsibge_balcadv subsibge_balarank, i(cnae2dgt subsibge) j(year)
order subsibge cnae2dgt
preserve
  tempfile balcibge
  keep subsibge*
  foreach year in 1990 1997 {
    rename subsibge_balcadv`year' balcadv_`year'
    rename subsibge_balarank`year' balarank_`year'
    }
  duplicates drop
  sort subsibge
  save `balcibge'
restore
  keep subsibge cnae*
  foreach year in 1990 1997 {
    rename cnae2dgt_balcadv`year' balcadv_`year'
    rename cnae2dgt_balarank`year' balarank_`year'
    }
append using `balcibge'
replace cnae2dgt = 0 if cnae2dgt==.
sort subsibge cnae2dgt
qui do brazrloc/auxil/cnae2dgt.do"
label values cnae2dgt cnae2dgt
qui do "rais/cnae/ibge.do"
label values subsibge ibge
decode subsibge, gen(_desc)
decode cnae2dgt, gen(desc)
replace desc = _desc if cnae2dgt==0
replace desc = substr(desc,1,50)
drop _desc
replace desc = "[2pt]" + string(subsibge) + " \"+"bf " + desc if cnae2dgt==0
replace desc = "\"+"quad " + string(cnae2dgt) + " " + desc if cnae2dgt~=0
sort subsibge cnae2dgt
gen byte tabcnae =  _n
order tabcnae desc balcadv_1990 balcadv_1997 balarank_1990 balarank_1997
drop subsibge cnae2dgt
count
forvalues i = 1/`r(N)' {
    local lblno = tabcnae[`i']
    local lbltit = desc[`i']
    label define tabcnae `lblno' "`lbltit'", add
    }
label values tabcnae tabcnae
qui label save tabcnae using "brazrloc/tex/v4/ext/summ/tabcnae", replace
gen str _rowname = string(tabcnae)
drop tabcnae desc
save "brazrloc/tex/v4/ext/summ/subscnae_tbl.dta", replace
matload subscnae_tbl, dropall p(brazrloc/tex/v4/ext/summ) over
est2tex subscnae, replace dropall preserve ready vallabel(tabcnae) p(brazrloc/tex/v4/ext/summ) extracols(2) fancy digits(3)


* NIV100 AND SUBSIBGE (via CNAE/ISIC2)
use `subsibge'
rename empl empl_chk
joinby isic2 using `niv100', unmatched(both) _merge(_merge)
tab _m
tab _m if niv100==.           // _m==1: nontraded sectors
tab _m if int(niv100/100)==1  // agriculture
gen _diff = empl - empl_chk
count if _diff~=0 & _diff~=.
if `r(N)'>0  STOP  // contradictory employment information
keep niv100 subsibge empl
duplicates drop
order niv100
sort niv100
drop if niv100==.
gen byte niv50 = int(niv100/100)
collapse (sum) empl, by(niv50 subsibge) fast
order niv50
sort niv50 subsibge
egen _maxempl = max(empl), by(niv50)
gen byte indmaxempl = ( empl==_maxempl )
drop _maxempl
gen byte niv50_num = niv50
gen byte subsibge_num = subsibge
label var niv50_num "Sector (Nivel 50)"
label var niv50 "Sector (Nivel 50)"
label var subsibge_num "Subsector IBGE"
label var empl "Employment at ISIC rev. 2"
label var indmaxempl "Max. employment at Nivel 50"
qui do "brazcomp/niv-cnae/niv100.do"
label values niv50 niv100
qui do "rais/cnae/ibge.do"
label values subsibge ibge
order niv50_num niv50 subsibge_num subsibge
sort niv50 subsibge
outsheet using "brazrloc/auxil/niv50-subsibge-pseudoconc.csv", comma replace
// Comparative Advantage Table for 1990 and 1997
insheet using "brazrloc/auxil/manual/niv50-subsibge-manual.csv", names comma clear
keep niv50_num subsibge_num
rename niv50_num niv50
rename subsibge_num subsibge
count if niv50==niv50[_n-1] | niv50==niv50[_n+1]
if `r(N)'>0  STOP  // concordance incomplete
duplicates tag niv50, gen(_dupl)
count if _dupl>0
if `r(N)'>0  STOP  // not a unique nivel 50 list
drop _dupl
joinby niv50 using "brazaux/intl/balassa-compadv-niv50", unmatched(both) _merge(_merge)
tab _m
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete sector mapping
drop _m
rename balcadv niv50_balcadv
rename balarank niv50_balarank
sort subsibge year
joinby subsibge year using "brazaux/intl/balassa-compadv-subsibge", unmatched(both) _merge(_merge)
tab _m
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete sector mapping
drop _m wrld_exp wrld_tot braz_exp braz_tot
rename balcadv subsibge_balcadv
rename balarank subsibge_balarank
keep if year==1990 | year==1997
reshape wide niv50_balcadv niv50_balarank subsibge_balcadv subsibge_balarank, i(niv50 subsibge) j(year)
order subsibge niv50
preserve
  tempfile balcibge
  keep subsibge*
  foreach year in 1990 1997 {
    rename subsibge_balcadv`year' balcadv_`year'
    rename subsibge_balarank`year' balarank_`year'
    }
  duplicates drop
  sort subsibge
  save `balcibge'
restore
  keep subsibge niv50*
  foreach year in 1990 1997 {
    rename niv50_balcadv`year' balcadv_`year'
    rename niv50_balarank`year' balarank_`year'
    }
append using `balcibge'
replace niv50 = 0 if niv50==.
sort subsibge niv50
qui do "brazcomp/niv-cnae/niv100.do"
label values niv50 niv100
qui do "rais/cnae/ibge.do"
label values subsibge ibge
decode subsibge, gen(_desc)
decode niv50, gen(desc)
replace desc = _desc if niv50==0
replace desc = substr(desc,1,50)
drop _desc
replace desc = "[2pt]" + string(subsibge) + "\"+"bf " + desc if niv50==0
replace desc = "\"+"quad " + string(niv50) + " " + desc if niv50~=0
sort subsibge niv50
gen byte tabniv50 =  _n
order tabniv50 desc balcadv_1990 balcadv_1997 balarank_1990 balarank_1997
drop subsibge niv50
count
forvalues i = 1/`r(N)' {
    local lblno = tabniv50[`i']
    local lbltit = desc[`i']
    label define tabniv50 `lblno' "`lbltit'", add
    }
label values tabniv50 tabniv50
qui label save tabniv50 using "brazrloc/tex/v4/ext/summ/tabniv50", replace
gen str _rowname = string(tabniv50)
drop tabniv50 desc
save "brazrloc/tex/v4/ext/summ/subsniv50_tbl.dta", replace
matload subsniv50_tbl, dropall p(brazrloc/tex/v4/ext/summ) over
est2tex subsniv50, replace dropall preserve ready vallabel(tabniv50) p(brazrloc/tex/v4/ext/summ) extracols(2) fancy digits(3)

log close
